Bifrost: Data Fields

Bifrost

Here is a list of all documented struct and union fields with links to the struct/union documentation for each field:

### - m -

- mappedSequenceToString() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- merge() : CCDBG_Data_t< Unitig_data_t > , CDBG_Data_t< Unitig_data_t, Graph_data_t > , ColoredCDBG< Unitig_data_t > , CompactedDBG< Unitig_data_t, Graph_data_t > , DataAccessor< Unitig_data_t >